// src/get-blob.ts
var getBlob = (url) => {
  return fetch(url).then((res) => res.blob());
};

// src/load-image.ts
var loadImage = (src) => {
  return new Promise((resolve, reject) => {
    const img = new Image();
    img.crossOrigin = "";
    img.src = src;
    img.onload = () => resolve(img);
    img.onerror = reject;
    img.onabort = reject;
  });
};

// src/read-as-data-url.ts
var readAsDataUrl = (blob) => {
  return new Promise((resolve, reject) => {
    const reader = new FileReader();
    reader.readAsDataURL(blob);
    reader.onload = () => resolve(reader.result);
    reader.onerror = reject;
    reader.onabort = reject;
  });
};

// src/to-array.ts
var toArray = (val) => {
  return Array.isArray(val) ? val : [val];
};

// src/index.ts
var consoleImg = async (url, options = {}) => {
  const {
    //
    width,
    height,
    fit = "contain",
    styles,
    debug
  } = options;
  const blob = await getBlob(url);
  const dataUrl = await readAsDataUrl(blob);
  const image = await loadImage(dataUrl);
  const ratio = image.naturalWidth / image.naturalHeight;
  const _width = width || (height ? height * ratio : image.naturalWidth);
  const _height = height || (width ? width / ratio : image.naturalHeight);
  const py = _height / 2;
  const px = _width / 2;
  const css = (url2 = dataUrl) => [
    "line-height: 0",
    `padding: ${py}px ${px}px`,
    `background: url(${url2}) no-repeat 50% / ${fit}`,
    styles && toArray(styles).join("; ")
  ].filter(Boolean).join("; ");
  console.log("%c ", css());
  if (debug) {
    console.log("[console.img]", css("data:image/png;base64,...").split("; "));
  }
  return image;
};
console.img = consoleImg;
var src_default = consoleImg;
export {
  consoleImg,
  src_default as default
};
